@@ -7,6 +7,6 @@ from .core import (
     PersistentJSON,
     ResultCollector,
 )
-from .datamanage import CompositeDataSource, DrioDataSource, NullDataSource
+from .datamanage import CompositeDataSource, DrioDataSource
 
-__version__ = "0.2.1"
+__version__ = "0.3.0"
